==> ngcode-0.0.2.tgz: package/readme.md <==
# IMPORTANT: STILL UNDER DEVELOPMENT

# NGCODE [![Build Status](https://secure.travis-ci.org/silverbux/ngcode.png)](http://travis-ci.org/silverbux/ngcode)

> An AngularJS code generator, implementing john papa's [angular-styleguide](https://github.com/johnpapa/angular-styleguide).


Install this globally and you'll have access to the ngcode command anywhere on your system.

```shell
npm install -g ngcode
```


#### Example Usage

##### Generate Directive
```
ngcode directive:mydirective
```

##### Generate Controller
```
ngcode controller:mycontroller
```

##### Generate Factory
```
ngcode factory:myfactory
```

##### Generate Module
```
ngcode module:mymodule
```


## LICENSE

(MIT License)

Copyright (c) 2014 aquiambao <alexquiambao@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> ngcode-0.0.5.tgz: package/readme.md <==
# NGCODE [![Build Status](https://secure.travis-ci.org/silverbux/ngcode.png)](http://travis-ci.org/silverbux/ngcode)

> An AngularJS code generator, implementing john papa's [angular-styleguide](https://github.com/johnpapa/angular-styleguide).


Install this globally and you'll have access to the ngcode command anywhere on your system.

```shell
npm install -g ngcode
```

### Example Usage:

#### Directive
```
ngcode directive:helloworld
```
*Shortcut*
```
ngcode dir:helloworld
```

----------

#### Controller
```
ngcode controller:helloworld
```
*Shortcut*
```
ngcode con:helloworld
```

----------

#### Service
```
ngcode service:helloworld
```
*Shortcut*
```
ngcode ser:helloworld
```

----------

#### Factory
```
ngcode factory:helloworld
```
*Shortcut*
```
ngcode fac:helloworld
```

----------

#### Filter
```
ngcode filter:helloworld
```
*Shortcut*
```
ngcode fil:helloworld
```


----------


#### Module
```
ngcode module:mymodule
```
*Shortcut*
```
ngcode mod:helloworld
```


## LICENSE

(MIT License)

Copyright (c) 2014 aquiambao <alexquiambao@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
